Learn R Programming

PoPdesign (version 1.1.0)

print.pop: Generate descriptive summary for objects returned by other functions

Description

Generate descriptive summary for objects returned by other functions.

Usage

# S3 method for pop
print(x, ...)

Value

print() prints the objects returned by other functions.

Arguments

x

the object returned by other functions

...

ignored arguments

Details

print() prints the objects returned by other functions.